@@ -382,7 +382,7 @@ These are the ones I use every day so they may be a good start:
 =head3 Smart docs
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/smart_docs_method.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/smart_docs_method.html">Screenshot</a> ]<p>
 
 
 C<C-o C-d> is the "Smart docs" command. It brings up POD documentation
@@ -561,7 +561,7 @@ See L<File::Corresponding> for details.
 =head3 Find with Ack
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/find_with_ack.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/find_with_ack.html">Screenshot</a> ]<p>
 
 
 C<C-o f a> -- Ack through the source and display the hits in a
@@ -596,7 +596,7 @@ something else using C<M-x rename-buffer>.
 =head3 Find sub declarations
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/find_sub_declaration.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/find_sub_declaration.html">Screenshot</a> ]<p>
 
 
 C<C-o f s> -- Ack the Project for I<sub declarations> of the method,
@@ -611,7 +611,7 @@ the object (C<$us|er_agent-E<gt>get()>).
 =head3 Find method calls
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/find_method_calls.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/find_method_calls.html">Screenshot</a> ]<p>
 
 
 C<C-o f c> -- Ack the Project for I<method calls> to the method, or
@@ -749,7 +749,7 @@ q -- Quit the Class Overview buffer.
 =head2 Testing
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/testing.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/testing.html">Screenshot</a> ]<p>
 
 
 =head3 Run File
@@ -824,10 +824,24 @@ line in the current buffer, so be sure to only run this when the
 B<*compilation*> buffer contains the run result of this buffer.
 
 
+=head3 Run Single Test::Class Method
+
+If you use L<Test::Class> to write your tests, you may sometimes want
+to run L<just a single test method|Test::Clas/RUNNING_INDIVIDUAL_TESTS>.
+
+Hit C<C-o r m> to mark the current sub as the current test method, and
+C<C-o r m> again to unmark it. This will set the $TEST_METHOD
+environment variable during program runs, so when you run this test
+class, only the marked method will be run.
+
+The current test method is indicated with a "Test::Class -->" next to
+it.
+
+
 =head3 Go to Tests - Other Files
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/goto_tests.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/goto_tests.html">Screenshot</a> ]<p>
 
 
 C<C-o g t o> -- In a test file, navigate to the source files that are
@@ -934,7 +948,7 @@ first).
 =head3 Flymake Introduction
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/flymake.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/flymake.html">Screenshot</a> ]<p>
 
 
 "Flymake performs on-the-fly syntax checks of the files being edited
@@ -1029,7 +1043,7 @@ is customized to a true value.
 =head3 Code Coverage Visualization Introduction
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/code_coverage.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/code_coverage.html">Screenshot</a> ]<p>
 
 
 If you have a test suite, you might like this. You should have tests.
@@ -1130,7 +1144,7 @@ you were, and continue doing what you where doing.
 =head3 Assist With -- Regex
 
 
-=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0180/doc/regex_tool.html">Screenshot</a> ]<p>
+=for html <p>[ <a href="http://search.cpan.org/src/JOHANL/Devel-PerlySense-0.0181/doc/regex_tool.html">Screenshot</a> ]<p>
 
 
 Hit C<C-o a r> to bring up the Regex Tool which will let you compose a
@@ -1577,7 +1591,7 @@ use strict;
 use warnings;
 
 package Devel::PerlySense;
-our $VERSION = '0.0180';
+our $VERSION = '0.0181';
 
 
 
